AgentFailure class final
A typed command or event failure.
- Implemented types
Constructors
- AgentFailure(AgentErrorCode code, String message, {required bool fatal})
-
Creates a failure with a stable code.
const
Properties
- code → AgentErrorCode
-
Stable machine-readable failure code.
final
- fatal → bool
-
Whether the session cannot continue.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable detail safe for application logs.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited