FlutterLocalVoiceAgentWeb class final
Web plugin registrant for this package.
The web session backend is constructed by LocalVoiceAgent.create. This registrant points the plugin manifest at this package and installs the production WASM guard plus session backend default.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
registerWith(
Registrar registrar) → void - Registers the plugin with Flutter web. No method channel is opened.